# Custom version of lpeg for Rosie Pattern Language

See [Rosie Pattern Language](https://gitlab.com/rosie-pattern-language/rosie).

The original lpeg implementation is [here](http://www.inf.puc-rio.br/~roberto/lpeg).
